@@ -4,7 +4,7 @@ use std::fmt;
 /// ICEProtocol indicates the transport protocol type that is used in the
 /// ice.URL structure.
 #[derive(Debug, Copy, Clone, PartialEq, Serialize, Deserialize)]
-pub enum ICEProtocol {
+pub enum RTCIceProtocol {
     Unspecified,
 
     /// UDP indicates the URL uses a UDP transport.
@@ -16,9 +16,9 @@ pub enum ICEProtocol {
     Tcp,
 }
 
-impl Default for ICEProtocol {
+impl Default for RTCIceProtocol {
     fn default() -> Self {
-        ICEProtocol::Unspecified
+        RTCIceProtocol::Unspecified
     }
 }
 
@@ -26,23 +26,23 @@ const ICE_PROTOCOL_UDP_STR: &str = "udp";
 const ICE_PROTOCOL_TCP_STR: &str = "tcp";
 
 /// takes a string and converts it to ICEProtocol
-impl From<&str> for ICEProtocol {
+impl From<&str> for RTCIceProtocol {
     fn from(raw: &str) -> Self {
         if raw.to_uppercase() == ICE_PROTOCOL_UDP_STR.to_uppercase() {
-            ICEProtocol::Udp
+            RTCIceProtocol::Udp
         } else if raw.to_uppercase() == ICE_PROTOCOL_TCP_STR.to_uppercase() {
-            ICEProtocol::Tcp
+            RTCIceProtocol::Tcp
         } else {
-            ICEProtocol::Unspecified
+            RTCIceProtocol::Unspecified
         }
     }
 }
 
-impl fmt::Display for ICEProtocol {
+impl fmt::Display for RTCIceProtocol {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
-            ICEProtocol::Udp => write!(f, "{}", ICE_PROTOCOL_UDP_STR),
-            ICEProtocol::Tcp => write!(f, "{}", ICE_PROTOCOL_TCP_STR),
+            RTCIceProtocol::Udp => write!(f, "{}", ICE_PROTOCOL_UDP_STR),
+            RTCIceProtocol::Tcp => write!(f, "{}", ICE_PROTOCOL_TCP_STR),
             _ => write!(f, "{}", crate::UNSPECIFIED_STR),
         }
     }
@@ -55,15 +55,15 @@ mod test {
     #[test]
     fn test_new_ice_protocol() {
         let tests = vec![
-            ("Unspecified", ICEProtocol::Unspecified),
-            ("udp", ICEProtocol::Udp),
-            ("tcp", ICEProtocol::Tcp),
-            ("UDP", ICEProtocol::Udp),
-            ("TCP", ICEProtocol::Tcp),
+            ("Unspecified", RTCIceProtocol::Unspecified),
+            ("udp", RTCIceProtocol::Udp),
+            ("tcp", RTCIceProtocol::Tcp),
+            ("UDP", RTCIceProtocol::Udp),
+            ("TCP", RTCIceProtocol::Tcp),
         ];
 
         for (proto_string, expected_proto) in tests {
-            let actual = ICEProtocol::from(proto_string);
+            let actual = RTCIceProtocol::from(proto_string);
             assert_eq!(expected_proto, actual);
         }
     }
@@ -71,9 +71,9 @@ mod test {
     #[test]
     fn test_ice_protocol_string() {
         let tests = vec![
-            (ICEProtocol::Unspecified, "Unspecified"),
-            (ICEProtocol::Udp, "udp"),
-            (ICEProtocol::Tcp, "tcp"),
+            (RTCIceProtocol::Unspecified, "Unspecified"),
+            (RTCIceProtocol::Udp, "udp"),
+            (RTCIceProtocol::Tcp, "tcp"),
         ];
 
         for (proto, expected_string) in tests {
